# Widgets Reference

Complete list of all Textual widgets available in the builder.

## Builder Schema

```{eval-rst}
.. autoclass:: genro_textual.textual_builder.TextualWidgetsMixin
   :members:
   :undoc-members:
```
